@@ -1,9 +1,6 @@
 package SVN::Hooks;
-{
-  $SVN::Hooks::VERSION = '1.27';
-}
 # ABSTRACT: Framework for implementing Subversion hooks
-
+$SVN::Hooks::VERSION = '1.29';
 use strict;
 use warnings;
 
@@ -38,10 +35,8 @@ sub run_hook {
 
         # The configuration file must be evaluated in the main:: namespace
 	package main;
-{
-  $main::VERSION = '1.27';
-}
-	unless (my $return = do $conffile) {
+$main::VERSION = '1.29';
+unless (my $return = do $conffile) {
 	    die "couldn't parse '$conffile': $@\n" if $@;
 	    die "couldn't do '$conffile': $!\n"    unless defined $return;
 	    die "couldn't run '$conffile'\n"       unless $return;
@@ -139,7 +134,7 @@ sub PRE_UNLOCK (&) {
     return;
 }
 
-# start-commit(repos-path, username, capabilities)
+# start-commit(repos-path, username, capabilities, txt-name)
 
 sub START_COMMIT (&) {
     my ($hook) = @_;
@@ -163,7 +158,7 @@ SVN::Hooks - Framework for implementing Subversion hooks
 
 =head1 VERSION
 
-version 1.27
+version 1.29
 
 =head1 SYNOPSIS
 
@@ -174,7 +169,7 @@ A single script can implement several hooks:
 	use SVN::Hooks;
 
 	START_COMMIT {
-	    my ($repo_path, $username, $capabilities) = @_;
+	    my ($repo_path, $username, $capabilities, $txt_name) = @_;
 	    # ...
 	};
 
@@ -351,7 +346,7 @@ L<SVN::Look> documentation to know how to use it.)
 
 =item * PRE_UNLOCK(repos-path, path, username, lock-token, break-unlock-flag)
 
-=item * START_COMMIT(repos-path, username, capabilities)
+=item * START_COMMIT(repos-path, username, capabilities, txt-name)
 
 =back
 
@@ -364,7 +359,7 @@ This is an example of a script implementing two hooks:
 	# ...
 
 	START_COMMIT {
-	    my ($repos_path, $username, $capabilities) = @_;
+	    my ($repos_path, $username, $capabilities, $txt_name) = @_;
 
 	    exists $committers{$username}
 		or die "User '$username' is not allowed to commit.\n";
@@ -560,7 +555,7 @@ called, like this:
 
 =over
 
-=item * start-commit repo-path user capabilities
+=item * start-commit repo-path user capabilities txt-name
 
 =item * pre-commit repo-path txn
 
@@ -585,13 +580,17 @@ the hooks, you usually call C<run_hook> like this:
 
 	run_hook($0, @ARGV);
 
+=head1 REPOSITORY
+
+L<https://github.com/gnustavo/SVN-Hooks>
+
 =head1 AUTHOR
 
 Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by CPqD.
+This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
