@@ -1,12 +1,9 @@
+package SVN::Hooks::UpdateConfFile;
+# ABSTRACT: Maintain the repository configuration versioned.
+$SVN::Hooks::UpdateConfFile::VERSION = '1.29';
 use strict;
 use warnings;
 
-package SVN::Hooks::UpdateConfFile;
-{
-  $SVN::Hooks::UpdateConfFile::VERSION = '1.26';
-}
-# ABSTRACT: Maintain the repository configuration versioned.
-
 use Carp;
 use Data::Util qw(:check);
 use File::Spec::Functions;
@@ -224,29 +221,30 @@ sub _post_where_to {
     } else {
         return if $file !~ $from;
         # interpolate backreferences
-        $to = eval qq{"$to"};   ## no critic
+        $to = eval qq{"$to"};   ## no critic (BuiltinFunctions::ProhibitStringyEval)
     }
 
-    my $is_directory = ($to =~ s:/$::);
-
-    my $abs_to = abs_path(catfile($absbase, $to));
-    if ($is_directory || -d $abs_to) {
-        $abs_to = catfile($abs_to, (File::Spec->splitpath($file))[2]);
-    }
-
-    $absbase eq substr($abs_to, 0, length($absbase))
+    $to !~ m@(?:^|/)\.\.(?:/|$)@
         or croak <<"EOS";
 $HOOK: post-commit aborted for: $file
 
 This means that $file was committed but the associated
 configuration file wasn't generated because its specified
-location ($abs_to)
-isn't below the repository's configuration directory
-($absbase).
+location ($to)
+contains a '..' path component which is not accepted by this hook.
 
 Please, correct the ${HOOK}'s second argument.
 EOS
 
+    my $is_directory = ($to =~ s:/$::);
+
+    $to =~ s:^/+::;
+
+    my $abs_to = catfile($absbase, $to);
+    if ($is_directory || -d $abs_to) {
+        $abs_to = catfile($abs_to, (File::Spec->splitpath($file))[2]);
+    }
+
     return $abs_to;
 }
 
@@ -276,7 +274,7 @@ SVN::Hooks::UpdateConfFile - Maintain the repository configuration versioned.
 
 =head1 VERSION
 
-version 1.26
+version 1.29
 
 =head1 SYNOPSIS
 
@@ -305,10 +303,11 @@ FROM can be a string or a qr/Regexp/ specifying the file path relative
 to the repository's root (e.g. "trunk/src/version.c" or
 "qr:^conf/(\w+).conf$:").
 
-TO is a path relative to the C</repo/conf> directory in the server. It can be
-an explicit file name or a directory, in which case the basename of FROM is
-used as the name of the destination file. Non-existing directory components of
-TO are automatically created.
+TO must be a relative path indicating where the original file must be copied
+to below the C</repo/conf> directory in the server. It can be an explicit
+file name or a directory, in which case the basename of FROM is used as the
+name of the destination file. Non-existing directory components of TO are
+automatically created.
 
 Note that if the path doesn't exist the hook assumes that it should be a
 file. To make sure it's understood as a directory you may end it with a
@@ -429,7 +428,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by CPqD.
+This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
