@@ -1,5 +1,3 @@
-# Copyright (C) 2008 by CPqD
-
 use strict;
 use warnings;
 use Cwd;
@@ -27,6 +25,19 @@ sub can_svn {
     return 1;
 }
 
+sub svn_version {
+    open my $pipe, '-|', "svn --version" or die;
+    my $version = <$pipe>;
+    local $/ = undef;           # slurp mode to read everything else up
+    <$pipe>;
+    close $pipe or die;
+    if ($version =~ /version ([\d\.]+)/) {
+        return $1;
+    } else {
+        die "Couldn't grok version from 'svn --version' command";
+    }
+}
+
 our $T;
 
 sub newdir {
@@ -115,7 +126,9 @@ EOS
     # ":/bin:/usr/bin". During the tests we try to set up the hooks so
     # that they will use the PATH as it is in the test environment.
     if (defined $ENV{PATH} and length $ENV{PATH}) {
-	print $fd "BEGIN { \$ENV{PATH} = '$ENV{PATH}' }\n";
+	my $path = $ENV{PATH};
+	$path =~ s/\\$//;
+	print $fd "BEGIN { \$ENV{PATH} = '$path' }\n";
     }
 
     if (defined $ENV{PERL5LIB} and length $ENV{PERL5LIB}) {
@@ -146,7 +159,7 @@ EOS
 	    $hookfile .= '.cmd';
 	    open my $fd, '>', $hookfile
 		or die "Can't create $hookfile: $!";
-+	    print $fd "\@echo off\n";
+	    print $fd "\@echo off\n";
 	    print $fd "$^X $hookscript $hook %1 %2 %3 %4 %5\n";
 	    close $fd;
 	    chmod 0755 => $hookfile;
